ytree\.tree\_farm\.ancestry\_filter\.AncestryFilter
===================================================

.. currentmodule:: ytree.tree_farm.ancestry_filter

.. autoclass:: AncestryFilter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AncestryFilter.__init__
   
   

   
   
   